=============
pyglet2d docs
=============

Contents
========

.. toctree::
   :maxdepth: 2

   overview
   reference/index
   contributing

.. include:: ../AUTHORS.rst

.. include:: ../CHANGELOG.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
